# dummit
dummy input tests (spelled /ˈdamɪt/)

nothing to be seen here just an attempt to start a skeleton for simple (i.e. dummy) input tests.

### Tests
![Tests class diagram](img/test_classes.png "Tests class diagram")

### Inputs
![Inputs class diagram](img/input_classes.png "Inputs class diagram")

### Locations
![Locations class diagram](img/location_classes.png "Locations class diagram")

### DataFrame Based Tests
![DataFrame Tests class diagram](img/df_test_classes.png "DataFrame Tests class diagram")

### And all the rest
![All the rest class diagram](img/all_other_classes.png "All the rest class diagram")
